<?php

/**
* @file
* Contains \Drupal\snippets\Form\SnippetsSettingsForm.
*/

namespace Drupal\instapage\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'instapage.settings',
    ];
  }

  public function getFormId() {
    return 'instapage_admin_settings_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('instapage.settings');

    $instapage_user_id = $config->get('instapage_user_id');
    $plugin_hash = $config->get('instapage_plugin_hash');

    if ($instapage_user_id && $plugin_hash) {
      $data = array(
        'id' => $instapage_user_id,
        'plugin_hash' => $plugin_hash,
      );

      $result = instapage_api_call('get-user', $data, 'GET');

      if ( isset( $result->error ) && $result->error == 1 ) {
        $form_state->setErrorByName('form', t('Error from Instapage API: @instapage_msg', array('@instapage_msg' => $result->error_message)));

        // Clear variables on form error to match the initial state.
        $config->set('instapage_user_id', false);
        $config->set('instapage_plugin_hash', false);
        $config->save();
      }
      else {
        // If user is logged in, show info and Disconnect button.
        $form['info']['#markup'] = t('You are logged in as @user.', array('@user' => $result->user));
        $form['info']['#markup'] .= '<p>' . t('Administer your pages <a href="@link">here</a>.', array('@link' => Url::fromRoute('instapage.landing_pages')->toString())) . '</p>';

        $form['actions']['#type'] = 'actions';
        $form['actions']['submit'] = array('#type' => 'submit', '#value' => t('Disconnect'));
        return $form;
      }
    }

    $form['info']['#markup'] = t('Type in email and password of your Instapage account.');
    $form['instapage_user_email'] = array(
      '#type' => 'textfield',
      '#title' => t('Email'),
      '#required' => TRUE,
    );

    $form['instapage_user_password'] = array(
      '#type' => 'password',
      '#title' => t('Password'),
      '#required' => TRUE,
    );

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = array('#type' => 'submit', '#value' => t('Save configuration'));

    return $form;

  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

    if ($this->config('instapage.settings')->get('instapage_user_id') == false) {
      $data = array(
        'email' => base64_encode(trim($form_state->getValue('instapage_user_email'))),
        'password' => base64_encode(trim($form_state->getValue('instapage_user_password'))),
      );

      $result = instapage_api_call('user-login', $data);

      if ($result) {
        if (isset($result->success)) {
          $form_state->setValue('instapage_user_id', $result->data->user_id);
          $form_state->setValue('instapage_plugin_hash', $result->data->plugin_hash);
        }
        else {
          if (isset($result->error) && $result->error == TRUE) {
            $form_state->setErrorByName('form', t('Error from Instapage API: @instapage_msg', array('@instapage_msg' => $result->error_message)));
          }
          else {
            $form_state->setErrorByName('form', $result->error_message);
          }
        }
      }
    }

  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('instapage.settings');

    if ($config->get('instapage_user_id') == false) {
      $config->set('instapage_user_id', $form_state->getValue('instapage_user_id'));
      $config->set('instapage_plugin_hash', $form_state->getValue('instapage_plugin_hash'));
      $config->save();
    }
    else {
      $config->set('instapage_user_id', false);
      $config->set('instapage_plugin_hash', false);
      $config->save();
    }

    parent::submitForm($form, $form_state);
  }

}